# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.table
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
    from .border_line import BorderLine as BorderLine_a3f80af6
    from .border_line2 import BorderLine2 as BorderLine2_af200b28
    from .shadow_format import ShadowFormat as ShadowFormat_bb840bdf
    from .table_border import TableBorder as TableBorder_aedf0b56
    from .table_border2 import TableBorder2 as TableBorder2_ba670b88
    from ..util.cell_protection import CellProtection as CellProtection_c9290c6d
    from ..util.color import Color as Color_68e908c5
    from com.sun.star.table.CellHoriJustify import CellHoriJustifyProto
    from com.sun.star.table.CellOrientation import CellOrientationProto

class CellProperties(XPropertySet_bc180bfa):
    """
    Service Class

    contains the properties of a table cell.
    
    **since**
    
        LibreOffice 4.3

    See Also:
        `API CellProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1table_1_1CellProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.CellProperties'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CellInteropGrabBag(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        Grab bag of cell properties, used as a string-any map for interim interop purposes.
        
        This property is intentionally not handled by the ODF filter. Any member that should be handled there should be first moved out from this grab bag to a separate property.
        
        **since**
        
            LibreOffice 4.3
        """
        ...

    @abstractproperty
    def AsianVerticalMode(self) -> bool:
        """
        selects Asian character orientation in vertical orientation.
        
        If the CellProperties.Orientation property is CellOrientation.STACKED, in Asian mode only Asian characters are printed in horizontal orientation instead of all characters. For other values of CellProperties.Orientation, this value is not used.
        """
        ...

    @abstractproperty
    def BottomBorder(self) -> BorderLine_a3f80af6:
        """
        contains a description of the bottom border line of each cell.
        """
        ...

    @abstractproperty
    def BottomBorder2(self) -> BorderLine2_af200b28:
        """
        contains a description of the bottom border line of each cell.
        
        Preferred over BorderLine BottomBorder.
        
        **since**
        
            LibreOffice 3.6
        """
        ...

    @abstractproperty
    def CellBackColor(self) -> Color_68e908c5:
        """
        contains the cell background color.
        """
        ...

    @abstractproperty
    def CellProtection(self) -> CellProtection_c9290c6d:
        """
        contains a description of the cell protection.
        
        Cell protection is active only if the sheet is protected.
        """
        ...

    @abstractproperty
    def CellStyle(self) -> str:
        """
        contains the name of the style of the cell.
        """
        ...

    @abstractproperty
    def DiagonalBLTR(self) -> BorderLine_a3f80af6:
        """
        contains a description of the bottom left to top right diagonal line of each cell.
        """
        ...

    @abstractproperty
    def DiagonalBLTR2(self) -> BorderLine2_af200b28:
        """
        contains a description of the bottom left to top right diagonal line of each cell.
        
        Preferred over BorderLine DiagonalBLTR.
        
        **since**
        
            LibreOffice 3.6
        """
        ...

    @abstractproperty
    def DiagonalTLBR(self) -> BorderLine_a3f80af6:
        """
        contains a description of the top left to bottom right diagonal line of each cell.
        """
        ...

    @abstractproperty
    def DiagonalTLBR2(self) -> BorderLine2_af200b28:
        """
        contains a description of the top left to bottom right diagonal line of each cell.
        
        Preferred over BorderLine DiagonalTLBR.
        
        **since**
        
            LibreOffice 3.6
        """
        ...

    @abstractproperty
    def HoriJustify(self) -> CellHoriJustifyProto:
        """
        contains the horizontal alignment of the cell contents.
        """
        ...

    @abstractproperty
    def IsCellBackgroundTransparent(self) -> bool:
        """
        is TRUE, if the cell background is transparent.
        
        In this case the CellProperties.CellBackColor value is not used.
        """
        ...

    @abstractproperty
    def IsTextWrapped(self) -> bool:
        """
        is TRUE, if text in the cells will be wrapped automatically at the right border.
        """
        ...

    @abstractproperty
    def LeftBorder(self) -> BorderLine_a3f80af6:
        """
        contains a description of the left border line of each cell.
        """
        ...

    @abstractproperty
    def LeftBorder2(self) -> BorderLine2_af200b28:
        """
        contains a description of the left border line of each cell.
        
        Preferred over BorderLine LeftBorder.
        
        **since**
        
            LibreOffice 3.6
        """
        ...

    @abstractproperty
    def NumberFormat(self) -> int:
        """
        contains the index of the number format that is used in the cells.
        
        The proper value can be determined by using the com.sun.star.util.NumberFormatter interface of the document.
        """
        ...

    @abstractproperty
    def Orientation(self) -> CellOrientationProto:
        """
        contains the orientation of the cell contents.
        
        If the CellProperties.RotateAngle property is non-zero, this value is not used.
        """
        ...

    @abstractproperty
    def ParaIndent(self) -> int:
        """
        defines the indentation of the cell contents (in 1/100 mm).
        """
        ...

    @abstractproperty
    def RightBorder(self) -> BorderLine_a3f80af6:
        """
        contains a description of the right border line of each cell.
        """
        ...

    @abstractproperty
    def RightBorder2(self) -> BorderLine2_af200b28:
        """
        contains a description of the right border line of each cell.
        
        Preferred over BorderLine RightBorder.
        
        **since**
        
            LibreOffice 3.6
        """
        ...

    @abstractproperty
    def RotateAngle(self) -> int:
        """
        defines how much the content of cells is rotated (in 1/100 degrees).
        """
        ...

    @abstractproperty
    def RotateReference(self) -> int:
        """
        defines at which edge rotated cells are aligned.
        
        changed from com.sun.star.table.CellVertJustify to long in LibO 3.5
        """
        ...

    @abstractproperty
    def ShadowFormat(self) -> ShadowFormat_bb840bdf:
        """
        contains a description of the shadow.
        """
        ...

    @abstractproperty
    def ShrinkToFit(self) -> bool:
        """
        is TRUE, if the cell content will be shrunk to fit in the cell.
        """
        ...

    @abstractproperty
    def TableBorder(self) -> TableBorder_aedf0b56:
        """
        contains a description of the cell or cell range border.
        
        If used with a cell range, the top, left, right, and bottom lines are at the edges of the entire range, not at the edges of the individual cell.
        """
        ...

    @abstractproperty
    def TableBorder2(self) -> TableBorder2_ba670b88:
        """
        contains a description of the cell or cell range border.
        
        Preferred over TableBorder TableBorder.
        
        If used with a cell range, the top, left, right, and bottom lines are at the edges of the entire range, not at the edges of the individual cell.
        
        **since**
        
            LibreOffice 3.6
        """
        ...

    @abstractproperty
    def TopBorder(self) -> BorderLine_a3f80af6:
        """
        contains a description of the top border line of each cell.
        """
        ...

    @abstractproperty
    def TopBorder2(self) -> BorderLine2_af200b28:
        """
        contains a description of the top border line of each cell.
        
        Preferred over BorderLine TopBorder.
        
        **since**
        
            LibreOffice 3.6
        """
        ...

    @abstractproperty
    def UserDefinedAttributes(self) -> XNameContainer_cb90e47:
        """
        stores additional attributes.
        
        This property is used i.e. by the XML filters to load and restore unknown attributes.
        """
        ...

    @abstractproperty
    def VertJustify(self) -> int:
        """
        contains the vertical alignment of the cell contents.
        
        changed from com.sun.star.table.CellVertJustify to long in LibO 3.5
        """
        ...


__all__ = ['CellProperties']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
from abc import abstractmethod
from .x_dispatch_provider import XDispatchProvider as XDispatchProvider_fc690de6

class XDispatchProviderInterceptor(XDispatchProvider_fc690de6):
    """
    makes it possible to intercept request of XDispatch.
    
    Can be registered as an interceptor by using interface XDispatchProviderInterception.

    See Also:
        `API XDispatchProviderInterceptor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XDispatchProviderInterceptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XDispatchProviderInterceptor'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XDispatchProviderInterceptor'

    @abstractmethod
    def getMasterDispatchProvider(self) -> XDispatchProvider_fc690de6:
        """
        access to the master XDispatchProvider of this interceptor
        """
        ...
    @abstractmethod
    def getSlaveDispatchProvider(self) -> XDispatchProvider_fc690de6:
        """
        access to the slave XDispatchProvider of this interceptor
        """
        ...
    @abstractmethod
    def setMasterDispatchProvider(self, NewSupplier: XDispatchProvider_fc690de6) -> None:
        """
        sets the master XDispatchProvider, which may forward calls to its XDispatchProvider.queryDispatch() to this dispatch provider.
        """
        ...
    @abstractmethod
    def setSlaveDispatchProvider(self, NewDispatchProvider: XDispatchProvider_fc690de6) -> None:
        """
        sets the slave XDispatchProvider to which calls to XDispatchProvider.queryDispatch() can be forwarded under control of this dispatch provider.
        """
        ...

__all__ = ['XDispatchProviderInterceptor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
from .x_layout_manager2 import XLayoutManager2 as XLayoutManager2_e1270cd6

class LayoutManager(XLayoutManager2_e1270cd6):
    """
    Service Class

    controls the layout of user interface elements which are part of a frame.
    
    Layout management is the process of determining the size and position of user interface elements. By default, each Frame has a layout manager – it performs layout management for the user interface elements within the frame. User interface elements can provide size and alignment hints to layout managers, but layout managers have the final decision on the size and position of those user interface elements.
    
    Available properties:
    
    **since**
    
        OOo 2.0

    See Also:
        `API LayoutManager <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1frame_1_1LayoutManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.LayoutManager'
    __ooo_type_name__: str = 'service'


__all__ = ['LayoutManager']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.uri.external_uri_reference_translator import ExternalUriReferenceTranslator as ExternalUriReferenceTranslator
from ...lo.uri.relative_uri_excess_parent_segments import RelativeUriExcessParentSegments as RelativeUriExcessParentSegments
from ...lo.uri.uri_reference_factory import UriReferenceFactory as UriReferenceFactory
from ...lo.uri.uri_scheme_parser_vnd_do_tsun_do_tstar_do_texpand import UriSchemeParser_vndDOTsunDOTstarDOTexpand as UriSchemeParser_vndDOTsunDOTstarDOTexpand
from ...lo.uri.uri_scheme_parser_vnd_do_tsun_do_tstar_do_tscript import UriSchemeParser_vndDOTsunDOTstarDOTscript as UriSchemeParser_vndDOTsunDOTstarDOTscript
from ...lo.uri.vnd_sun_star_pkg_url_reference_factory import VndSunStarPkgUrlReferenceFactory as VndSunStarPkgUrlReferenceFactory
from ...lo.uri.x_external_uri_reference_translator import XExternalUriReferenceTranslator as XExternalUriReferenceTranslator
from ...lo.uri.x_uri_reference import XUriReference as XUriReference
from ...lo.uri.x_uri_reference_factory import XUriReferenceFactory as XUriReferenceFactory
from ...lo.uri.x_uri_scheme_parser import XUriSchemeParser as XUriSchemeParser
from ...lo.uri.x_vnd_sun_star_expand_url import XVndSunStarExpandUrl as XVndSunStarExpandUrl
from ...lo.uri.x_vnd_sun_star_expand_url_reference import XVndSunStarExpandUrlReference as XVndSunStarExpandUrlReference
from ...lo.uri.x_vnd_sun_star_pkg_url_reference_factory import XVndSunStarPkgUrlReferenceFactory as XVndSunStarPkgUrlReferenceFactory
from ...lo.uri.x_vnd_sun_star_script_url import XVndSunStarScriptUrl as XVndSunStarScriptUrl
from ...lo.uri.x_vnd_sun_star_script_url_reference import XVndSunStarScriptUrlReference as XVndSunStarScriptUrlReference



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
from abc import abstractproperty
from .base_storage import BaseStorage as BaseStorage_ae680b55
from .x_encryption_protected_source import XEncryptionProtectedSource as XEncryptionProtectedSource_8cdf11a3
from .x_transacted_object import XTransactedObject as XTransactedObject_fb510dbd
from .x_transaction_broadcaster import XTransactionBroadcaster as XTransactionBroadcaster_576e104d

class Storage(BaseStorage_ae680b55, XEncryptionProtectedSource_8cdf11a3, XTransactedObject_fb510dbd, XTransactionBroadcaster_576e104d):
    """
    Service Class

    This is a service that allows to get access to a package using storage hierarchy.
    
    A root storage should be retrieved by using StorageFactory service. Substorages are created through XStorage interface of a parent storage.

    See Also:
        `API Storage <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1embed_1_1Storage.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.Storage'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def HasEncryptedEntries(self) -> bool:
        """
        allows to detect if the storage contains encrypted entries.
        
        In case it is set to TRUE the storage itself and/or a tree of substorages contain encrypted streams. Usually in case this property is supported the implementation supports XEncryptionProtectedSource interface.
        """
        ...

    @abstractproperty
    def HasNonEncryptedEntries(self) -> bool:
        """
        allows to detect if the storage contains non-encrypted entries.
        
        In case it is set to TRUE the storage itself and/or a tree of substorages contains non-encrypted streams. Usually in case this property is supported the implementation supports XEncryptionProtectedSource interface.
        """
        ...

    @abstractproperty
    def IsRoot(self) -> bool:
        """
        allows to detect whether the storage is a root one.
        """
        ...

    @abstractproperty
    def MediaType(self) -> str:
        """
        allows to get and set the media type of the storage.
        """
        ...

    @abstractproperty
    def MediaTypeFallbackIsUsed(self) -> bool:
        """
        allows to detect whether mediatype is detected by using fallback approach.
        
        Can be set to true if the mediatype can not be detected in standard way, but there is a fallback solution allows to do it.
        
        Usually means that the document validity is questionable, although the package itself is not corrupted. The decision about document validity in this case is in application hands. It is up to user of the storage to decide whether he accepts the fallback approach for an implementation of this service, outputs a warning or an error.
        """
        ...

    @abstractproperty
    def RepairPackage(self) -> bool:
        """
        allows to detect whether storage is open in \"repair package\" mode or not.
        """
        ...

    @abstractproperty
    def Version(self) -> str:
        """
        allows to get and set the version of the format related to the MediaType.
        """
        ...


__all__ = ['Storage']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing.framework
from __future__ import annotations
import typing
from abc import abstractmethod
from ...lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .configuration_change_event import ConfigurationChangeEvent as ConfigurationChangeEvent_55151590

class XConfigurationChangeListener(XEventListener_c7230c4a):
    """
    A listener for configuration changes is called when it has been registered at the configuration controller and a configuration change occurs.

    See Also:
        `API XConfigurationChangeListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XConfigurationChangeListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.XConfigurationChangeListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.framework.XConfigurationChangeListener'

    @abstractmethod
    def notifyConfigurationChange(self, aEvent: ConfigurationChangeEvent_55151590) -> None:
        """
        The exact time of when a listener is called (before the change takes place, during the change, or when the change has been made) depends on the change event.
        
        The order in which listeners are called is the order in which they are registered (First registered, first called.)
        """
        ...

__all__ = ['XConfigurationChangeListener']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_document_properties import XDocumentProperties as XDocumentProperties_4c31102b
    from ..embed.x_storage import XStorage as XStorage_8e460a32
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4

class XOOXMLDocumentPropertiesImporter(XInterface_8f010a43):
    """
    allows to import the document properties from OOXML format
    
    **since**
    
        LibreOffice 7.3

    See Also:
        `API XOOXMLDocumentPropertiesImporter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XOOXMLDocumentPropertiesImporter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.XOOXMLDocumentPropertiesImporter'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.document.XOOXMLDocumentPropertiesImporter'

    @abstractmethod
    def getCorePropertiesStream(self, xSource: XStorage_8e460a32) -> XInputStream_98d40ab4:
        """
        find and get core properties stream
        
        (usually it is docProps\\core.xml)
        
        **since**
        
            LibreOffice 7.3
        """
        ...
    @abstractmethod
    def getCustomPropertiesStreams(self, xSource: XStorage_8e460a32) -> typing.Tuple[XInputStream_98d40ab4, ...]:
        """
        find and get custom properties streams
        
        (usually it is customXml*.xml)
        
        **since**
        
            LibreOffice 7.3
        """
        ...
    @abstractmethod
    def getExtendedPropertiesStream(self, xSource: XStorage_8e460a32) -> XInputStream_98d40ab4:
        """
        find and get extended properties stream
        
        (usually it is docProps/app.xml)
        
        **since**
        
            LibreOffice 7.3
        """
        ...
    @abstractmethod
    def importProperties(self, xSource: XStorage_8e460a32, xDocumentProperties: XDocumentProperties_4c31102b) -> None:
        """
        allows to import the document properties from OOXML format
        
        The implementation should parse the document properties from OOXML format storage and set them to the target XDocumentProperties implementation.
        
        The storage must represent OOXML format and support com.sun.star.embed.XRelationshipAccess interface. Please see com.sun.star.embed.StorageFactory for details regarding creation of such a storage.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.xml.sax.SAXException: ``SAXException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...

__all__ = ['XOOXMLDocumentPropertiesImporter']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..embed.x_storage import XStorage as XStorage_8e460a32

class XUIConfigurationPersistence(XInterface_8f010a43):
    """
    specifies a persistence interface which supports to load/store user interface configuration data to a storage and to retrieve information about the current state.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XUIConfigurationPersistence <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XUIConfigurationPersistence.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.XUIConfigurationPersistence'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.XUIConfigurationPersistence'

    @abstractmethod
    def isModified(self) -> bool:
        """
        provides the current modify state of the configuration manager instance.
        """
        ...
    @abstractmethod
    def isReadOnly(self) -> bool:
        """
        provides the current read-only state of the user configuration manager.
        
        Storing a user interface configuration to a read-only storage is not possible. A read-only configuration manager instance will also not support any changes to its configuration settings.
        """
        ...
    @abstractmethod
    def reload(self) -> None:
        """
        reloads the configuration data from the storage and reinitialize the user interface configuration manager instance with this data.
        
        It is up to the implementation if it defers the first loading process until the first data request using XUIConfigurationManager interface.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def store(self) -> None:
        """
        stores the configuration data to the storage provided by setStorage() from the storage and initialize the user interface configuration manager instance with the newly data.
        
        This call can throw an com.sun.star.io.IOException if store() cannot store its data into the internal storage.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def storeToStorage(self, Storage: XStorage_8e460a32) -> None:
        """
        stores the configuration data to the provided storage, ignoring the previously set storage by setStorage().
        
        Can be used to make copy of the current user interface configuration data to another storage. This call will throw an com.sun.star.io.IOException if the provided storage is in read-only mode.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
        ...

__all__ = ['XUIConfigurationPersistence']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
from abc import abstractproperty
from .connection_properties import ConnectionProperties as ConnectionProperties_1a9f0ee1

class FILEConnectionProperties(ConnectionProperties_1a9f0ee1):
    """
    Service Class

    represents the properties for a FILE connection (session) with a specific database.
    
    These properties can be used when calling the method com.sun.star.sdbc.XDriver.connect() or com.sun.star.sdbc.XDriverManager.getConnectionWithInfo().
    
    The properties for a connection contain additional information about how to connect to a database and how to control the behavior of the resulting connection should be.

    See Also:
        `API FILEConnectionProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbc_1_1FILEConnectionProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.FILEConnectionProperties'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CharSet(self) -> str:
        """
        specifies the encoding to use to translate the backend data
        
        See the IANA character set list for a list of valid values.
        
        For internal purposes (e.g., when using an encoding for which no IANA character set name exists), this may also be an UNSIGNED SHORT value representing one of the rtl_TextEncoding values in rtl/textenc.h.
        """
        ...


__all__ = ['FILEConnectionProperties']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.component
from __future__ import annotations
import typing
from abc import abstractproperty
from ..x_reset import XReset as XReset_71670917
from ..x_submit import XSubmit as XSubmit_7b060988
from .form import Form as Form_ca1d0c51
if typing.TYPE_CHECKING:
    from com.sun.star.form.FormSubmitEncoding import FormSubmitEncodingProto
    from com.sun.star.form.FormSubmitMethod import FormSubmitMethodProto

class HTMLForm(Form_ca1d0c51, XReset_71670917, XSubmit_7b060988):
    """
    Service Class

    This service specifies the special kind of Forms for HTML documents.
    
    An HTMLForm fulfills the specification of forms in HTML. It supplies the possibility of submitting or resetting the contents of a form. For more information on HTML forms, please see the documentation of HTML.

    See Also:
        `API HTMLForm <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1HTMLForm.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.component'
    __ooo_full_ns__: str = 'com.sun.star.form.component.HTMLForm'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def SubmitEncoding(self) -> FormSubmitEncodingProto:
        """
        specifies the kind of encoding for submission.
        """
        ...

    @abstractproperty
    def SubmitMethod(self) -> FormSubmitMethodProto:
        """
        specifies the kind of submission.
        """
        ...

    @abstractproperty
    def TargetFrame(self) -> str:
        """
        describes the frame, where to open the document specified by the TargetURL.
        """
        ...

    @abstractproperty
    def TargetURL(self) -> str:
        """
        specifies the URL, which should be used for submission.
        """
        ...


__all__ = ['HTMLForm']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script.provider
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ...document.x_script_invocation_context import XScriptInvocationContext as XScriptInvocationContext_a29f1233
    from ...frame.x_desktop import XDesktop as XDesktop_8e740a45
    from ...frame.x_model import XModel as XModel_7a6e095c
    from ...uno.x_component_context import XComponentContext as XComponentContext_e2e10d4a

class XScriptContext(XInterface_8f010a43):
    """
    This interface is provided to scripts, and provides a means of access to the various interfaces which they might need to perform some action on a document.
    
    It is required to be passed as the first argument for any Java scripts.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XScriptContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1provider_1_1XScriptContext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script.provider'
    __ooo_full_ns__: str = 'com.sun.star.script.provider.XScriptContext'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.provider.XScriptContext'

    @abstractmethod
    def getComponentContext(self) -> XComponentContext_e2e10d4a:
        """
        Obtain the component context which the script can use to create other uno components.
        """
        ...
    @abstractmethod
    def getDesktop(self) -> XDesktop_8e740a45:
        """
        Obtain the desktop reference on which the script can operate.
        """
        ...
    @abstractmethod
    def getDocument(self) -> XModel_7a6e095c:
        """
        Obtain the document reference on which the script can operate.
        """
        ...
    @abstractmethod
    def getInvocationContext(self) -> XScriptInvocationContext_a29f1233:
        """
        provides access to the context where the script was invoked
        
        In some cases, it is possible that scripts, embedded in a document, are executed from within a context which is not the document itself. In this case, the getInvocationContext member allows to access this context.
        
        Note that the returned context is allowed to be NULL, in this case, the document as returned by getDocument is the invocation context.
        
        If the returned context is not NULL, its ScriptContainer attribute equals the document as returned by XScriptContext.getDocument.
        
        **since**
        
            OOo 3.0
        """
        ...

__all__ = ['XScriptContext']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
from ..container.x_hierarchical_name_container import XHierarchicalNameContainer as XHierarchicalNameContainer_d6621306
from ..frame.x_component_loader import XComponentLoader as XComponentLoader_eede0d75
from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6
from .definition_container import DefinitionContainer as DefinitionContainer_fc1e0ded
from .definition_content import DefinitionContent as DefinitionContent_e0d20d25

class DocumentContainer(DefinitionContainer_fc1e0ded, DefinitionContent_e0d20d25, XHierarchicalNameContainer_d6621306, XComponentLoader_eede0d75, XMultiServiceFactory_191e0eb6):
    """
    Service Class

    describes a container which provides access to documents embedded into a database document, usually forms and reports.
    
    The com.sun.star.lang.XMultiServiceFactory.createInstanceWithArguments() should be used to create sub document container or form, or report objects.
    
    The embedded documents do not support any particular database related service, instead, they're usual com.sun.star.document.OfficeDocuments.The only thing worth mentioning here is that they support the com.sun.star.container.XChild interface, whose com.sun.star.container.XChild.getParent() method can be used to obtain the database document which the embedded document belongs to.

    See Also:
        `API DocumentContainer <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DocumentContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.DocumentContainer'
    __ooo_type_name__: str = 'service'


__all__ = ['DocumentContainer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_fast_property_set import XFastPropertySet as XFastPropertySet_ee6b0d88
from ..beans.x_multi_property_set import XMultiPropertySet as XMultiPropertySet_fd880e05
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..frame.x_controller import XController as XController_b00e0b8f

class PropertyBrowserController(XFastPropertySet_ee6b0d88, XMultiPropertySet_fd880e05, XPropertySet_bc180bfa, XController_b00e0b8f):
    """
    Service Class

    describes a controller which can be used to browse and modify properties of form controls.
    
    The controller can be plugged into a com.sun.star.frame.XFrame, and will provide a visual component for inspecting control properties. This means it allows to interactively control several aspects of a FormControlModel or DataAwareControlModel, such as it's data binding, it's layout, and it's event binding
    
    For using a PropertyBrowserController, you need to
    
    Note that nowadays, this service is only a legacy wrapper using the com.sun.star.inspection.ObjectInspector and the com.sun.star.form.inspection.DefaultFormComponentInspectorModel services, and knitting them together.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API PropertyBrowserController <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1PropertyBrowserController.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.PropertyBrowserController'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CurrentPage(self) -> str:
        """
        controls the actually visible page.
        
        The aspects of a DataAwareControlModel which can be browsed and modified using this controller can be separated into 3 groups: common aspects, data-awareness related aspects, and bound events.The appearance of the visual component created by the controller is that 3 tab pages, one for each group, are displayed (of course if the control does not support any aspects of a given group, the group is omitted).With this property, it can be controller which page is currently active.
        
        Valid values are (this list may be extended in the future):
        """
        ...

    @abstractproperty
    def IntrospectedObject(self) -> XPropertySet_bc180bfa:
        """
        contains the object to inspect.
        
        Changing this property from outside causes the controller to update its view with the data of the new object
        """
        ...


__all__ = ['PropertyBrowserController']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class MemberResult(object):
    """
    Struct Class

    describes a result of a DataPilot member.
    
    **since**
    
        LibreOffice 5.3

    See Also:
        `API MemberResult <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1MemberResult.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.MemberResult'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sheet.MemberResult'
    """Literal Constant ``com.sun.star.sheet.MemberResult``"""

    def __init__(self, Name: typing.Optional[str] = '', Caption: typing.Optional[str] = '', Flags: typing.Optional[int] = 0, Value: typing.Optional[float] = 0.0) -> None:
        """
        Constructor

        Arguments:
            Name (str, optional): Name value.
            Caption (str, optional): Caption value.
            Flags (int, optional): Flags value.
            Value (float, optional): Value value.
        """
        super().__init__()

        if isinstance(Name, MemberResult):
            oth: MemberResult = Name
            self.Name = oth.Name
            self.Caption = oth.Caption
            self.Flags = oth.Flags
            self.Value = oth.Value
            return

        kargs = {
            "Name": Name,
            "Caption": Caption,
            "Flags": Flags,
            "Value": Value,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._name = kwargs["Name"]
        self._caption = kwargs["Caption"]
        self._flags = kwargs["Flags"]
        self._value = kwargs["Value"]


    @property
    def Name(self) -> str:
        """
        the internal name of the field.
        """
        return self._name

    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value

    @property
    def Caption(self) -> str:
        """
        the visible name of the field.
        """
        return self._caption

    @Caption.setter
    def Caption(self, value: str) -> None:
        self._caption = value

    @property
    def Flags(self) -> int:
        """
        contains flags describing the result.
        """
        return self._flags

    @Flags.setter
    def Flags(self, value: int) -> None:
        self._flags = value

    @property
    def Value(self) -> float:
        """
        the underlying numeric value of the field if Flags indicate so by having com.sun.star.sheet.MemberResultFlags.NUMERIC set.
        
        May be NaN if value is not available or unknown.
        
        **since**
        
            LibreOffice 5.3
        """
        return self._value

    @Value.setter
    def Value(self, value: float) -> None:
        self._value = value


__all__ = ['MemberResult']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.awt.MenuItemType import MenuItemTypeProto

class MenuItemType(Enum):
    """
    Enum Class


    See Also:
        `API MenuItemType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt.html#a0014b68cdf9686458deff56691368317>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.MenuItemType'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.awt.MenuItemType'

    DONTKNOW = cast("MenuItemTypeProto", 'DONTKNOW')
    """
    specifies a font with an unknown slant.
    
    specifies that the menu item type is unknown.
    """
    IMAGE = cast("MenuItemTypeProto", 'IMAGE')
    """
    specifies that the menu item has an image.
    """
    SEPARATOR = cast("MenuItemTypeProto", 'SEPARATOR')
    """
    specifies that the menu item is a separator.
    """
    STRING = cast("MenuItemTypeProto", 'STRING')
    """
    specifies that the menu item has a text.
    """
    STRINGIMAGE = cast("MenuItemTypeProto", 'STRINGIMAGE')
    """
    specifies that the menu item has a text and an image.
    """

__all__ = ['MenuItemType']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
import uno
from enum import IntFlag
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class Aspects(metaclass=UnoConstMeta, type_name="com.sun.star.embed.Aspects", name_space="com.sun.star.embed"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.embed.Aspects``"""
        pass

    class AspectsEnum(IntFlag, metaclass=ConstEnumMeta, type_name="com.sun.star.embed.Aspects", name_space="com.sun.star.embed"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.embed.Aspects`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.embed import Aspects as Aspects
    else:
        # keep document generators happy
        from ...lo.embed.aspects import Aspects as Aspects

    class AspectsEnum(IntFlag):
        """
        Enum of Const Class Aspects

        The constant set contains possible aspects for an embedded object.
        
        This constant set provides a set of values that can be used to specify the kind of object view. It can be used for example by container to request view representation of a certain kind from XEmbeddedObject.
        
        The first 32 bits are reserved for MS OLE aspects.
        """
        MSOLE_CONTENT = Aspects.MSOLE_CONTENT
        """
        specifies view of the object to be displayed as an embedded object inside a container.
        """
        MSOLE_THUMBNAIL = Aspects.MSOLE_THUMBNAIL
        """
        specifies view of the object to be displayed in a browsing tool.
        """
        MSOLE_ICON = Aspects.MSOLE_ICON
        """
        specifies view of the object when object is represented by Icon.
        """
        MSOLE_DOCPRINT = Aspects.MSOLE_DOCPRINT
        """
        specifies view of the object for print preview.
        """

__all__ = ['Aspects', 'AspectsEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
from .chart_data import ChartData as ChartData_98ce0a86
from .x_chart_data_array import XChartDataArray as XChartDataArray_df4c0cdd

class ChartDataArray(ChartData_98ce0a86, XChartDataArray_df4c0cdd):
    """
    Service Class

    must be supported by each data source for charts, where you want to access the values directly.
    
    It contains the data values as well as the descriptions for each row and column.

    See Also:
        `API ChartDataArray <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1ChartDataArray.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.ChartDataArray'
    __ooo_type_name__: str = 'service'


__all__ = ['ChartDataArray']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.graphic
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..geometry.real_rectangle2_d import RealRectangle2D as RealRectangle2D_d9b0e03

class XPrimitive2D(XInterface_8f010a43):
    """
    XPrimitive2D interface.
    
    This is the basic interface for 2D graphic primitives. They need to be able

    See Also:
        `API XPrimitive2D <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1graphic_1_1XPrimitive2D.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.graphic'
    __ooo_full_ns__: str = 'com.sun.star.graphic.XPrimitive2D'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.graphic.XPrimitive2D'

    @abstractmethod
    def getDecomposition(self, aViewParameters: typing.Tuple[PropertyValue_c9610c73, ...]) -> typing.Tuple[XPrimitive2D, ...]:
        """
        Retrieve decomposed list of simpler primitives.
        
        com.sun.star.geometry.AffineMatrix2D Transformation
        
        A transformation matrix which maps between world coordinates (which is equal to object's local coordinates) to view coordinates. If not defined, an empty transformation is implied.
        
        com.sun.star.geometry.RealRectangle2D Viewport
        
        Defines the visible part of the view in world coordinates. May be used to optimize decompositions, e.g. for 3D scenes only the visible part needs to be created. If not given, an empty Viewport is implied which means all is visible.
        
        double Time
        
        Defines the point in time for which the geometry is defined. This may lead to varied results for animated objects. This value is defined in the range [0.0 .. n[, negative values are not allowed. If not given, a value of 0.0 is implied.
        """
        ...
    @abstractmethod
    def getRange(self, aViewParameters: typing.Tuple[PropertyValue_c9610c73, ...]) -> RealRectangle2D_d9b0e03:
        """
        Retrieve bound rect of primitive.
        
        This method calculates the actual bound rect of the area in world coordinates. Note that for view-dependent primitives, the necessary pixel adjustments are taken into account. For that reason the ViewParameters need to be given.
        """
        ...

__all__ = ['XPrimitive2D']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_load_listener import XLoadListener as XLoadListener_bb200bda

class XLoadable(XInterface_8f010a43):
    """
    provides functionality to implement objects which may be loaded.
    
    The object is typically implemented by high-level objects which can connect to a data source.

    See Also:
        `API XLoadable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1XLoadable.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.XLoadable'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.XLoadable'

    @abstractmethod
    def addLoadListener(self, aListener: XLoadListener_bb200bda) -> None:
        """
        adds the specified listener to receive load-related events
        """
        ...
    @abstractmethod
    def isLoaded(self) -> bool:
        """
        returns if the object is in loaded state.
        """
        ...
    @abstractmethod
    def load(self) -> None:
        """
        loads the data.
        
        If the data is already loaded (->isLoaded), then the method returns silently. In this case, you should use ->reload.
        """
        ...
    @abstractmethod
    def reload(self) -> None:
        """
        does a smart refresh of the object.
        
        The final state will be the same as if unload and load were called, but reload is the more efficient way to do the same. If the object isn't loaded, nothing happens.
        """
        ...
    @abstractmethod
    def removeLoadListener(self, aListener: XLoadListener_bb200bda) -> None:
        """
        removes the specified listener.
        """
        ...
    @abstractmethod
    def unload(self) -> None:
        """
        unloads the data.
        """
        ...

__all__ = ['XLoadable']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.system


class SystemShellExecuteFlags(object):
    """
    Const Class

    Different settings for the SystemShellExecute service.
    
    **since**
    
        LibreOffice 3.6

    See Also:
        `API SystemShellExecuteFlags <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1system_1_1SystemShellExecuteFlags.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.system'
    __ooo_full_ns__: str = 'com.sun.star.system.SystemShellExecuteFlags'
    __ooo_type_name__: str = 'const'

    DEFAULTS = 0
    """
    Uses the default settings for executing commands.
    """
    NO_SYSTEM_ERROR_MESSAGE = 1
    """
    Prevents the display of system error message boxes if the method com.sun.star.system.XSystemShellExecute.execute() fails.
    """
    URIS_ONLY = 2
    """
    Only allows opening of absolute URI references.
    
    **since**
    
        LibreOffice 3.6
    """

__all__ = ['SystemShellExecuteFlags']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from .rectangle import Rectangle as Rectangle_84b109e9
    from .x_focus_listener import XFocusListener as XFocusListener_bb8e0bf2
    from .x_key_listener import XKeyListener as XKeyListener_a4020b1b
    from .x_mouse_listener import XMouseListener as XMouseListener_bc1d0bfb
    from .x_mouse_motion_listener import XMouseMotionListener as XMouseMotionListener_c6a0e71
    from .x_paint_listener import XPaintListener as XPaintListener_bb6d0bee
    from .x_window_listener import XWindowListener as XWindowListener_c8aa0c6a

class XWindow(XComponent_98dc0ab5):
    """
    specifies the basic operations for a window component.
    
    A window is a rectangular region on an output device with its own position, size, and internal coordinate system. A window is used for displaying data. In addition, the window receives events from the user.

    See Also:
        `API XWindow <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XWindow.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XWindow'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XWindow'

    @abstractmethod
    def addFocusListener(self, xListener: XFocusListener_bb8e0bf2) -> None:
        """
        adds a focus listener to the object.
        """
        ...
    @abstractmethod
    def addKeyListener(self, xListener: XKeyListener_a4020b1b) -> None:
        """
        adds a key listener to the object.
        """
        ...
    @abstractmethod
    def addMouseListener(self, xListener: XMouseListener_bc1d0bfb) -> None:
        """
        adds a mouse listener to the object.
        """
        ...
    @abstractmethod
    def addMouseMotionListener(self, xListener: XMouseMotionListener_c6a0e71) -> None:
        """
        adds a mouse motion listener to the object.
        """
        ...
    @abstractmethod
    def addPaintListener(self, xListener: XPaintListener_bb6d0bee) -> None:
        """
        adds a paint listener to the object.
        """
        ...
    @abstractmethod
    def addWindowListener(self, xListener: XWindowListener_c8aa0c6a) -> None:
        """
        adds a window listener to the object.
        """
        ...
    @abstractmethod
    def getPosSize(self) -> Rectangle_84b109e9:
        """
        returns the outer bounds of the window.
        """
        ...
    @abstractmethod
    def removeFocusListener(self, xListener: XFocusListener_bb8e0bf2) -> None:
        """
        removes the specified focus listener from the listener list.
        """
        ...
    @abstractmethod
    def removeKeyListener(self, xListener: XKeyListener_a4020b1b) -> None:
        """
        removes the specified key listener from the listener list.
        """
        ...
    @abstractmethod
    def removeMouseListener(self, xListener: XMouseListener_bc1d0bfb) -> None:
        """
        removes the specified mouse listener from the listener list.
        """
        ...
    @abstractmethod
    def removeMouseMotionListener(self, xListener: XMouseMotionListener_c6a0e71) -> None:
        """
        removes the specified mouse motion listener from the listener list.
        """
        ...
    @abstractmethod
    def removePaintListener(self, xListener: XPaintListener_bb6d0bee) -> None:
        """
        removes the specified paint listener from the listener list.
        """
        ...
    @abstractmethod
    def removeWindowListener(self, xListener: XWindowListener_c8aa0c6a) -> None:
        """
        removes the specified window listener from the listener list.
        """
        ...
    @abstractmethod
    def setEnable(self, Enable: bool) -> None:
        """
        enables or disables the window depending on the parameter.
        """
        ...
    @abstractmethod
    def setFocus(self) -> None:
        """
        sets the focus to the window.
        """
        ...
    @abstractmethod
    def setPosSize(self, X: int, Y: int, Width: int, Height: int, Flags: int) -> None:
        """
        sets the outer bounds of the window.
        """
        ...
    @abstractmethod
    def setVisible(self, Visible: bool) -> None:
        """
        shows or hides the window depending on the parameter.
        """
        ...

__all__ = ['XWindow']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2
from __future__ import annotations
from .x_chart_document import XChartDocument as XChartDocument_dd6f0cd5
from .x_titled import XTitled as XTitled_8d490a0a
from .data.x_data_receiver import XDataReceiver as XDataReceiver_117d0e1b
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca
from ..style.x_style_families_supplier import XStyleFamiliesSupplier as XStyleFamiliesSupplier_4c5a1020
from ..util.x_number_formats_supplier import XNumberFormatsSupplier as XNumberFormatsSupplier_3afb0fb7

class ChartDocument(XChartDocument_dd6f0cd5, XTitled_8d490a0a, XDataReceiver_117d0e1b, XInitialization_d46c0cca, XStyleFamiliesSupplier_4c5a1020, XNumberFormatsSupplier_3afb0fb7):
    """
    Service Class


    See Also:
        `API ChartDocument <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart2_1_1ChartDocument.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.ChartDocument'
    __ooo_type_name__: str = 'service'


__all__ = ['ChartDocument']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XDictionaryEntry(XInterface_8f010a43):
    """
    This interfaces gives access to a dictionary entry.
    
    A dictionary entry can supply a word and its hyphenation and indicate if it is a negative word. If it is a negative entry it may supply a replacement text to be used instead of the entry word.
    
    Hyphenation positions are represented by an \"=\" in the word. If the \"=\" is the last character of the word this means it should not be hyphenated. If there is no \"=\" charter in the word, hyphenation positions will be determined automatically (i.e., from the hyphenator service alone).
    
    Entries whose words only differ in hyphenation are considered to be equal. Also a \".\" at the end of the word will make no difference.

    See Also:
        `API XDictionaryEntry <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XDictionaryEntry.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.XDictionaryEntry'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.linguistic2.XDictionaryEntry'

    @abstractmethod
    def getDictionaryWord(self) -> str:
        """
        """
        ...
    @abstractmethod
    def getReplacementText(self) -> str:
        """
        is the suggested replacement text for negative words.
        
        It is undefined if the entry is not negative.
        """
        ...
    @abstractmethod
    def isNegative(self) -> bool:
        """
        """
        ...

__all__ = ['XDictionaryEntry']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from .insert_command_argument import InsertCommandArgument as InsertCommandArgument_19550eb9
from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
import typing


class InsertCommandArgument2(InsertCommandArgument_19550eb9):
    """
    Struct Class

    The argument for the command \"insert\" augmented with some properties.

    See Also:
        `API InsertCommandArgument2 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1InsertCommandArgument2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.InsertCommandArgument2'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.InsertCommandArgument2'
    """Literal Constant ``com.sun.star.ucb.InsertCommandArgument2``"""

    def __init__(self, Data: typing.Optional[XInputStream_98d40ab4] = None, ReplaceExisting: typing.Optional[bool] = False, MimeType: typing.Optional[str] = '', DocumentId: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Data (XInputStream, optional): Data value.
            ReplaceExisting (bool, optional): ReplaceExisting value.
            MimeType (str, optional): MimeType value.
            DocumentId (str, optional): DocumentId value.
        """

        if isinstance(Data, InsertCommandArgument2):
            oth: InsertCommandArgument2 = Data
            self.Data = oth.Data
            self.ReplaceExisting = oth.ReplaceExisting
            self.MimeType = oth.MimeType
            self.DocumentId = oth.DocumentId
            return

        kargs = {
            "Data": Data,
            "ReplaceExisting": ReplaceExisting,
            "MimeType": MimeType,
            "DocumentId": DocumentId,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._mime_type = kwargs["MimeType"]
        self._document_id = kwargs["DocumentId"]
        inst_keys = ('MimeType', 'DocumentId')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def MimeType(self) -> str:
        """
        contains the MIME type of the document to insert
        """
        return self._mime_type

    @MimeType.setter
    def MimeType(self, value: str) -> None:
        self._mime_type = value

    @property
    def DocumentId(self) -> str:
        """
        contains the Document Id of the document to insert
        """
        return self._document_id

    @DocumentId.setter
    def DocumentId(self, value: str) -> None:
        self._document_id = value


__all__ = ['InsertCommandArgument2']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.datatransfer.dnd
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from .drag_source_event import DragSourceEvent as DragSourceEvent_8ccf115c
from ...uno.x_interface import XInterface as XInterface_8f010a43
from .x_drag_source_context import XDragSourceContext as XDragSourceContext_c2661297
from .x_drag_source import XDragSource as XDragSource_49900fb2
import typing


class DragSourceDropEvent(DragSourceEvent_8ccf115c):
    """
    Struct Class

    The DragSourceDropEvent is delivered from an object that implements XDragSourceContext to its currently registered drag source listener's.
    
    It contains sufficient information for the originator of the operation to provide appropriate feedback to the end user when the operation completes.

    See Also:
        `API DragSourceDropEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1DragSourceDropEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.datatransfer.dnd'
    __ooo_full_ns__: str = 'com.sun.star.datatransfer.dnd.DragSourceDropEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.datatransfer.dnd.DragSourceDropEvent'
    """Literal Constant ``com.sun.star.datatransfer.dnd.DragSourceDropEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, DragSourceContext: typing.Optional[XDragSourceContext_c2661297] = None, DragSource: typing.Optional[XDragSource_49900fb2] = None, DropAction: typing.Optional[int] = 0, DropSuccess: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            DragSourceContext (XDragSourceContext, optional): DragSourceContext value.
            DragSource (XDragSource, optional): DragSource value.
            DropAction (int, optional): DropAction value.
            DropSuccess (bool, optional): DropSuccess value.
        """

        if isinstance(Source, DragSourceDropEvent):
            oth: DragSourceDropEvent = Source
            self.Source = oth.Source
            self.DragSourceContext = oth.DragSourceContext
            self.DragSource = oth.DragSource
            self.DropAction = oth.DropAction
            self.DropSuccess = oth.DropSuccess
            return

        kargs = {
            "Source": Source,
            "DragSourceContext": DragSourceContext,
            "DragSource": DragSource,
            "DropAction": DropAction,
            "DropSuccess": DropSuccess,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._drop_action = kwargs["DropAction"]
        self._drop_success = kwargs["DropSuccess"]
        inst_keys = ('DropAction', 'DropSuccess')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def DropAction(self) -> int:
        """
        The action performed by the target on the subject of the drop.
        """
        return self._drop_action

    @DropAction.setter
    def DropAction(self, value: int) -> None:
        self._drop_action = value

    @property
    def DropSuccess(self) -> bool:
        """
        Indicates if the drop was successful.
        """
        return self._drop_success

    @DropSuccess.setter
    def DropSuccess(self, value: bool) -> None:
        self._drop_success = value


__all__ = ['DragSourceDropEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_window_peer import XWindowPeer as XWindowPeer_99760ab0
if typing.TYPE_CHECKING:
    from .font_descriptor import FontDescriptor as FontDescriptor_bc110c0a
    from ..util.color import Color as Color_68e908c5

class XVclWindowPeer(XWindowPeer_99760ab0):
    """
    gives access to the VCL window implementation.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XVclWindowPeer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XVclWindowPeer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XVclWindowPeer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XVclWindowPeer'

    @abstractmethod
    def enableClipSiblings(self, bClip: bool) -> None:
        """
        enables clipping of sibling windows.
        """
        ...
    @abstractmethod
    def getProperty(self, PropertyName: str) -> object:
        """
        returns the value of the property with the specified name.
        """
        ...
    @abstractmethod
    def getStyles(self, nType: int, Font: FontDescriptor_bc110c0a, ForegroundColor: Color_68e908c5, BackgroundColor: Color_68e908c5) -> None:
        """
        returns the font, foreground and background color for the specified type.

        * ``Font`` is an out direction argument.
        * ``ForegroundColor`` is an out direction argument.
        * ``BackgroundColor`` is an out direction argument.
        """
        ...
    @abstractmethod
    def isChild(self, Peer: XWindowPeer_99760ab0) -> bool:
        """
        returns TRUE if the window peer is a child, FALSE otherwise.
        """
        ...
    @abstractmethod
    def isDesignMode(self) -> bool:
        """
        returns TRUE if the window peer is in design mode, FALSE otherwise.
        """
        ...
    @abstractmethod
    def setControlFont(self, aFont: FontDescriptor_bc110c0a) -> None:
        """
        sets the control font.
        """
        ...
    @abstractmethod
    def setDesignMode(self, bOn: bool) -> None:
        """
        sets the design mode for use in a design editor.
        """
        ...
    @abstractmethod
    def setForeground(self, Color: Color_68e908c5) -> None:
        """
        sets the foreground color.
        """
        ...
    @abstractmethod
    def setProperty(self, PropertyName: str, Value: object) -> None:
        """
        sets the value of the property with the specified name.
        """
        ...

__all__ = ['XVclWindowPeer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractproperty
from .base_index import BaseIndex as BaseIndex_8f0d0a40
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa
    from .x_document_index_mark import XDocumentIndexMark as XDocumentIndexMark_fe490de7

class DocumentIndex(BaseIndex_8f0d0a40):
    """
    Service Class

    specifies service of content indexes within a document.

    See Also:
        `API DocumentIndex <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1DocumentIndex.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.DocumentIndex'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def DocumentIndexMarks(self) -> typing.Tuple[XDocumentIndexMark_fe490de7, ...]:
        """
        contains all index marks that are related to this index.
        """
        ...

    @abstractproperty
    def IsCaseSensitive(self) -> bool:
        """
        determines if the similarity of index entries is checked case sensitively.
        """
        ...

    @abstractproperty
    def Locale(self) -> Locale_70d308fa:
        """
        contains the locale of the index.
        """
        ...

    @abstractproperty
    def MainEntryCharacterStyleName(self) -> str:
        """
        determines the name of the character style that is applied to the number of a page where main index entry is located.
        """
        ...

    @abstractproperty
    def SortAlgorithm(self) -> str:
        """
        contains the name of the sort algorithm that is used to sort the entries.
        """
        ...

    @abstractproperty
    def UseAlphabeticalSeparators(self) -> bool:
        """
        determines if alphabetical separators are generated.
        """
        ...

    @abstractproperty
    def UseCombinedEntries(self) -> bool:
        """
        determines if same entries on different pages are combined into one index entry.
        """
        ...

    @abstractproperty
    def UseDash(self) -> bool:
        """
        determines if following page numbers are displayed using a dash.
        """
        ...

    @abstractproperty
    def UseKeyAsEntry(self) -> bool:
        """
        determines if an index entry is generated for each primary/secondary key.
        """
        ...

    @abstractproperty
    def UsePP(self) -> bool:
        """
        determines if following page numbers are displayed using a \"pp.\".
        """
        ...

    @abstractproperty
    def UseUpperCase(self) -> bool:
        """
        determines if all entries start with a capital letter.
        """
        ...


__all__ = ['DocumentIndex']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ....lo.datatransfer.dnd.dnd_constants import DNDConstants as DNDConstants
from ....lo.datatransfer.dnd.drag_gesture_event import DragGestureEvent as DragGestureEvent
from ....lo.datatransfer.dnd.drag_source_drag_event import DragSourceDragEvent as DragSourceDragEvent
from ....lo.datatransfer.dnd.drag_source_drop_event import DragSourceDropEvent as DragSourceDropEvent
from ....lo.datatransfer.dnd.drag_source_event import DragSourceEvent as DragSourceEvent
from ....lo.datatransfer.dnd.drop_target_drag_enter_event import DropTargetDragEnterEvent as DropTargetDragEnterEvent
from ....lo.datatransfer.dnd.drop_target_drag_event import DropTargetDragEvent as DropTargetDragEvent
from ....lo.datatransfer.dnd.drop_target_drop_event import DropTargetDropEvent as DropTargetDropEvent
from ....lo.datatransfer.dnd.drop_target_event import DropTargetEvent as DropTargetEvent
from ....lo.datatransfer.dnd.invalid_dnd_operation_exception import InvalidDNDOperationException as InvalidDNDOperationException
from ....lo.datatransfer.dnd.ole_drag_source import OleDragSource as OleDragSource
from ....lo.datatransfer.dnd.ole_drop_target import OleDropTarget as OleDropTarget
from ....lo.datatransfer.dnd.x11_drag_source import X11DragSource as X11DragSource
from ....lo.datatransfer.dnd.x11_drop_target import X11DropTarget as X11DropTarget
from ....lo.datatransfer.dnd.x_autoscroll import XAutoscroll as XAutoscroll
from ....lo.datatransfer.dnd.x_drag_gesture_listener import XDragGestureListener as XDragGestureListener
from ....lo.datatransfer.dnd.x_drag_gesture_recognizer import XDragGestureRecognizer as XDragGestureRecognizer
from ....lo.datatransfer.dnd.x_drag_source import XDragSource as XDragSource
from ....lo.datatransfer.dnd.x_drag_source_context import XDragSourceContext as XDragSourceContext
from ....lo.datatransfer.dnd.x_drag_source_listener import XDragSourceListener as XDragSourceListener
from ....lo.datatransfer.dnd.x_drop_target import XDropTarget as XDropTarget
from ....lo.datatransfer.dnd.x_drop_target_drag_context import XDropTargetDragContext as XDropTargetDragContext
from ....lo.datatransfer.dnd.x_drop_target_drop_context import XDropTargetDropContext as XDropTargetDropContext
from ....lo.datatransfer.dnd.x_drop_target_listener import XDropTargetListener as XDropTargetListener



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from ..io.x_stream import XStream as XStream_678908a4

class XOptimizedStorage(ABC):
    """
    This is a temporary interface that is introduced to temporarily optimize the document storing process.
    
    PLEASE DO NOT USE IT, it might change in any time and will be deprecated soon! Another solution will be introduced as final one.

    See Also:
        `API XOptimizedStorage <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XOptimizedStorage.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.XOptimizedStorage'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.embed.XOptimizedStorage'

    @abstractmethod
    def attachToURL(self, sURL: str, bReadOnly: bool) -> None:
        """
        allows to switch storage persistence to the provided URL.
        
        The caller is responsible to be sure that the file referenced by the URL contains the same contents as the stream the storage is based currently. Thus using of this method is very dangerous and should be avoided when possible. It is applicable only for root storages.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
        ...
    @abstractmethod
    def copyElementDirectlyTo(self, sSourceName: str, xTargetStorage: XOptimizedStorage, sTargetName: str) -> None:
        """
        allows to copy storage element directly, not guaranteed to work.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
        ...
    @abstractmethod
    def copyStreamElementData(self, sStreamName: str, xTargetStream: XStream_678908a4) -> None:
        """
        fills the provided stream with the last flushed version of data from the child stream of the storage.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.packages.WrongPasswordException: ``WrongPasswordException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
        ...
    @abstractmethod
    def getElementPropertyValue(self, sElementName: str, sPropertyName: str) -> object:
        """
        allows to get property of the child element with the specified name.
        
        The implementation of the method might allow to access only subset of the supported by element properties.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.beans.PropertyVetoException: ``PropertyVetoException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
        ...
    @abstractmethod
    def insertRawNonEncrStreamElementDirect(self, sStreamName: str, xInStream: XInputStream_98d40ab4) -> None:
        """
        allows to insert a raw stream representing non-encrypted stream with header.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.packages.NoRawFormatException: ``NoRawFormatException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
        ...
    @abstractmethod
    def insertStreamElementDirect(self, sStreamName: str, xInStream: XInputStream_98d40ab4, aProperties: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        allows to insert a stream to the storage directly.
        
        The stream must stay alive till the storage is committed.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
        ...
    @abstractmethod
    def writeAndAttachToStream(self, xStream: XStream_678908a4) -> None:
        """
        allows to switch storage persistence to the provided stream.
        
        The stream will be filled by the storage. If an empty reference is provided, the storage will create a temporary stream to switch to itself. It is applicable only for root storages.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
        ...

__all__ = ['XOptimizedStorage']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from __future__ import annotations
from abc import abstractmethod
from .x_calendar import XCalendar as XCalendar_888d09ba

class XExtendedCalendar(XCalendar_888d09ba):
    """
    This interface provides access to locale specific calendar systems.
    
    It is derived from com.sun.star.i18n.XCalendar and provides additional functionality to display parts of the date currently set at the calendar.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XExtendedCalendar <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XExtendedCalendar.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.XExtendedCalendar'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.i18n.XExtendedCalendar'

    @abstractmethod
    def getDisplayString(self, nCalendarDisplayCode: int, nNativeNumberMode: int) -> str:
        """
        Returns a string (number or name to display) matching the given code constant.
        
        Note that the string returned depends completely on the locale's calendar. It is not predictable if the string will be numeric or a name, or if in case it returns a numeric string how many digits that will have. For example, a short year display string will normally be two digits with a Gregorian calendar, but with a Jewish calendar it will have three digits.
        """
        ...

__all__ = ['XExtendedCalendar']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.animations
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class AnimationCalcMode(metaclass=UnoConstMeta, type_name="com.sun.star.animations.AnimationCalcMode", name_space="com.sun.star.animations"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.animations.AnimationCalcMode``"""
        pass

    class AnimationCalcModeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.animations.AnimationCalcMode", name_space="com.sun.star.animations"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.animations.AnimationCalcMode`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.animations import AnimationCalcMode as AnimationCalcMode
    else:
        # keep document generators happy
        from ...lo.animations.animation_calc_mode import AnimationCalcMode as AnimationCalcMode

    class AnimationCalcModeEnum(IntEnum):
        """
        Enum of Const Class AnimationCalcMode

        Specifies the interpolation mode for the animation.
        """
        DISCRETE = AnimationCalcMode.DISCRETE
        """
        This specifies that the animation function will jump from one value to the next without any interpolation.
        """
        LINEAR = AnimationCalcMode.LINEAR
        """
        Simple linear interpolation between values is used to calculate the animation function.
        
        This is the default.
        """
        PACED = AnimationCalcMode.PACED
        """
        Defines interpolation to produce an even pace of change across the animation.
        
        This is only supported for values that define a linear numeric range, and for which some notion of \"distance\" between points can be calculated (e.g. position, width, height, etc.).
        """
        SPLINE = AnimationCalcMode.SPLINE
        """
        Interpolates from one value in the values list to the next according to a time function defined by a cubic Bezier spline.
        
        The points of the spline are defined in the XAnimate.KeyTimes attribute, and the control points for each interval are defined in the XAnimate.TimeFilter attribute.
        """

__all__ = ['AnimationCalcMode', 'AnimationCalcModeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.script.all_event_object import AllEventObject as AllEventObject
with suppress(ImportError):
    from ...dyn.script.all_listener_adapter import AllListenerAdapter as AllListenerAdapter
with suppress(ImportError):
    from ...dyn.script.array_wrapper import ArrayWrapper as ArrayWrapper
with suppress(ImportError):
    from ...dyn.script.basic_error_exception import BasicErrorException as BasicErrorException
with suppress(ImportError):
    from ...dyn.script.cannot_convert_exception import CannotConvertException as CannotConvertException
with suppress(ImportError):
    from ...dyn.script.cannot_create_adapter_exception import CannotCreateAdapterException as CannotCreateAdapterException
with suppress(ImportError):
    from ...dyn.script.context_information import ContextInformation as ContextInformation
with suppress(ImportError):
    from ...dyn.script.converter import Converter as Converter
with suppress(ImportError):
    from ...dyn.script.document_dialog_library_container import DocumentDialogLibraryContainer as DocumentDialogLibraryContainer
with suppress(ImportError):
    from ...dyn.script.document_script_library_container import DocumentScriptLibraryContainer as DocumentScriptLibraryContainer
with suppress(ImportError):
    from ...dyn.script.engine import Engine as Engine
with suppress(ImportError):
    from ...dyn.script.event_listener import EventListener as EventListener
with suppress(ImportError):
    from ...dyn.script.fail_reason import FailReason as FailReason
with suppress(ImportError):
    from ...dyn.script.fail_reason import FailReasonEnum as FailReasonEnum
with suppress(ImportError):
    from ...dyn.script.finish_engine_event import FinishEngineEvent as FinishEngineEvent
with suppress(ImportError):
    from ...dyn.script.finish_reason import FinishReason as FinishReason
with suppress(ImportError):
    from ...dyn.script.interrupt_engine_event import InterruptEngineEvent as InterruptEngineEvent
with suppress(ImportError):
    from ...dyn.script.interrupt_reason import InterruptReason as InterruptReason
with suppress(ImportError):
    from ...dyn.script.invocation import Invocation as Invocation
with suppress(ImportError):
    from ...dyn.script.invocation_adapter_factory import InvocationAdapterFactory as InvocationAdapterFactory
with suppress(ImportError):
    from ...dyn.script.invocation_info import InvocationInfo as InvocationInfo
with suppress(ImportError):
    from ...dyn.script.java_script import JavaScript as JavaScript
with suppress(ImportError):
    from ...dyn.script.library_not_loaded_exception import LibraryNotLoadedException as LibraryNotLoadedException
with suppress(ImportError):
    from ...dyn.script.member_type import MemberType as MemberType
with suppress(ImportError):
    from ...dyn.script.module_info import ModuleInfo as ModuleInfo
with suppress(ImportError):
    from ...dyn.script.module_size_exceeded_request import ModuleSizeExceededRequest as ModuleSizeExceededRequest
with suppress(ImportError):
    from ...dyn.script.module_type import ModuleType as ModuleType
with suppress(ImportError):
    from ...dyn.script.module_type import ModuleTypeEnum as ModuleTypeEnum
with suppress(ImportError):
    from ...dyn.script.native_object_wrapper import NativeObjectWrapper as NativeObjectWrapper
with suppress(ImportError):
    from ...dyn.script.script_event import ScriptEvent as ScriptEvent
with suppress(ImportError):
    from ...dyn.script.script_event_descriptor import ScriptEventDescriptor as ScriptEventDescriptor
with suppress(ImportError):
    from ...dyn.script.x_all_listener import XAllListener as XAllListener
with suppress(ImportError):
    from ...dyn.script.x_all_listener_adapter_service import XAllListenerAdapterService as XAllListenerAdapterService
with suppress(ImportError):
    from ...dyn.script.x_automation_invocation import XAutomationInvocation as XAutomationInvocation
with suppress(ImportError):
    from ...dyn.script.x_debugging import XDebugging as XDebugging
with suppress(ImportError):
    from ...dyn.script.x_default_method import XDefaultMethod as XDefaultMethod
with suppress(ImportError):
    from ...dyn.script.x_default_property import XDefaultProperty as XDefaultProperty
with suppress(ImportError):
    from ...dyn.script.x_direct_invocation import XDirectInvocation as XDirectInvocation
with suppress(ImportError):
    from ...dyn.script.x_engine import XEngine as XEngine
with suppress(ImportError):
    from ...dyn.script.x_engine_listener import XEngineListener as XEngineListener
with suppress(ImportError):
    from ...dyn.script.x_error_query import XErrorQuery as XErrorQuery
with suppress(ImportError):
    from ...dyn.script.x_event_attacher import XEventAttacher as XEventAttacher
with suppress(ImportError):
    from ...dyn.script.x_event_attacher2 import XEventAttacher2 as XEventAttacher2
with suppress(ImportError):
    from ...dyn.script.x_event_attacher_manager import XEventAttacherManager as XEventAttacherManager
with suppress(ImportError):
    from ...dyn.script.x_invocation import XInvocation as XInvocation
with suppress(ImportError):
    from ...dyn.script.x_invocation2 import XInvocation2 as XInvocation2
with suppress(ImportError):
    from ...dyn.script.x_invocation_adapter_factory import XInvocationAdapterFactory as XInvocationAdapterFactory
with suppress(ImportError):
    from ...dyn.script.x_invocation_adapter_factory2 import XInvocationAdapterFactory2 as XInvocationAdapterFactory2
with suppress(ImportError):
    from ...dyn.script.x_library_access import XLibraryAccess as XLibraryAccess
with suppress(ImportError):
    from ...dyn.script.x_library_container import XLibraryContainer as XLibraryContainer
with suppress(ImportError):
    from ...dyn.script.x_library_container2 import XLibraryContainer2 as XLibraryContainer2
with suppress(ImportError):
    from ...dyn.script.x_library_container3 import XLibraryContainer3 as XLibraryContainer3
with suppress(ImportError):
    from ...dyn.script.x_library_container_export import XLibraryContainerExport as XLibraryContainerExport
with suppress(ImportError):
    from ...dyn.script.x_library_container_password import XLibraryContainerPassword as XLibraryContainerPassword
with suppress(ImportError):
    from ...dyn.script.x_library_query_executable import XLibraryQueryExecutable as XLibraryQueryExecutable
with suppress(ImportError):
    from ...dyn.script.x_persistent_library_container import XPersistentLibraryContainer as XPersistentLibraryContainer
with suppress(ImportError):
    from ...dyn.script.x_script_events_attacher import XScriptEventsAttacher as XScriptEventsAttacher
with suppress(ImportError):
    from ...dyn.script.x_script_events_supplier import XScriptEventsSupplier as XScriptEventsSupplier
with suppress(ImportError):
    from ...dyn.script.x_script_listener import XScriptListener as XScriptListener
with suppress(ImportError):
    from ...dyn.script.x_service_documenter import XServiceDocumenter as XServiceDocumenter
with suppress(ImportError):
    from ...dyn.script.x_star_basic_access import XStarBasicAccess as XStarBasicAccess
with suppress(ImportError):
    from ...dyn.script.x_star_basic_dialog_info import XStarBasicDialogInfo as XStarBasicDialogInfo
with suppress(ImportError):
    from ...dyn.script.x_star_basic_library_info import XStarBasicLibraryInfo as XStarBasicLibraryInfo
with suppress(ImportError):
    from ...dyn.script.x_star_basic_module_info import XStarBasicModuleInfo as XStarBasicModuleInfo
with suppress(ImportError):
    from ...dyn.script.x_storage_based_library_container import XStorageBasedLibraryContainer as XStorageBasedLibraryContainer
with suppress(ImportError):
    from ...dyn.script.x_type_converter import XTypeConverter as XTypeConverter
with suppress(ImportError):
    from ...dyn.script.the_service_documenter import theServiceDocumenter as theServiceDocumenter



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.accessibility
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .accessible_relation import AccessibleRelation as AccessibleRelation_8f8b119c

class XAccessibleRelationSet(XInterface_8f010a43):
    """
    Implement this interface to give access to an object's set of relations.
    
    Such relation are modeled with the AccessibleRelation structure. This interface is used for representing sets of relations between Accessible objects. Most of the convenience methods of the corresponding AccessibleRelationSet interface of the Java Accessibility API have been removed from this interface in order to clean it up. These methods are add(), addAll(), clear(), and remove(). The other methods have been renamed to achieve a greater conformance with the other accessibility interfaces.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessibleRelationSet <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleRelationSet.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.accessibility'
    __ooo_full_ns__: str = 'com.sun.star.accessibility.XAccessibleRelationSet'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.accessibility.XAccessibleRelationSet'

    @abstractmethod
    def containsRelation(self, aRelationType: int) -> bool:
        """
        Tests whether the relation set contains a relation matching the specified key.
        """
        ...
    @abstractmethod
    def getRelation(self, nIndex: int) -> AccessibleRelation_8f8b119c:
        """
        Returns the relation of this relation set that is specified by the given index.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getRelationByType(self, aRelationType: int) -> AccessibleRelation_8f8b119c:
        """
        Retrieve and return the relation with the given relation type.
        """
        ...
    @abstractmethod
    def getRelationCount(self) -> int:
        """
        Returns the number of relations in this relation set.
        """
        ...

__all__ = ['XAccessibleRelationSet']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.datatransfer.dnd
from __future__ import annotations
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XDropTargetDropContext(XInterface_8f010a43):
    """
    This interface is implemented by any drop target context object.
    
    A DropTargetContext is created whenever the logical cursor associated with a Drag and Drop operation moves within the visible geometry of a window associated with a DropTarget.
    
    The drop target context provides the mechanism for a potential receiver of a drop operation to provide the end user with the appropriate drag under feedback and to effect the subsequent data transfer, if appropriate.

    See Also:
        `API XDropTargetDropContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDropTargetDropContext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.datatransfer.dnd'
    __ooo_full_ns__: str = 'com.sun.star.datatransfer.dnd.XDropTargetDropContext'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.datatransfer.dnd.XDropTargetDropContext'

    @abstractmethod
    def acceptDrop(self, dragOperation: int) -> None:
        """
        Accept the Drop.
        
        This method should be called from the com.sun.star.datatransfer.dnd.XDropTargetListener.drop() method if the implementation wishes to accept the drop operation with the specified action.
        """
        ...
    @abstractmethod
    def dropComplete(self, success: bool) -> None:
        """
        Signals that the drop is completed and if it was successful or not.
        
        A value of FALSE means the drop completed unsuccessfully.
        """
        ...
    @abstractmethod
    def rejectDrop(self) -> None:
        """
        Reject the drop as a result of examining the available com.sun.star.datatransfer.DataFlavor types received in the XDropTargetListener.dragEnter() method.
        """
        ...

__all__ = ['XDropTargetDropContext']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
from .x_content_provider import XContentProvider as XContentProvider_d4150cc0

class WebDAVContentProvider(XContentProvider_d4150cc0):
    """
    Service Class

    The WebDAV Content Provider (DCP) implements a ContentProvider for the UniversalContentBroker (UCB).
    
    It provides access to WebDAV and standard HTTP servers. The DCP communicates with the server using the WebDAV protocol which is an extension to the HTTP protocol or using the plain HTTP protocol in case the server is not WebDAV enabled.

    See Also:
        `API WebDAVContentProvider <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ucb_1_1WebDAVContentProvider.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.WebDAVContentProvider'
    __ooo_type_name__: str = 'service'


__all__ = ['WebDAVContentProvider']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt.tree
from __future__ import annotations
from abc import abstractmethod, abstractproperty
from .x_tree_node import XTreeNode as XTreeNode_baaf0ba0

class XMutableTreeNode(XTreeNode_baaf0ba0):
    """
    Represents a mutable tree node as used by the MutableTreeDataModel.

    See Also:
        `API XMutableTreeNode <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XMutableTreeNode.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt.tree'
    __ooo_full_ns__: str = 'com.sun.star.awt.tree.XMutableTreeNode'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.tree.XMutableTreeNode'

    @abstractmethod
    def appendChild(self, ChildNode: XMutableTreeNode) -> None:
        """
        appends ChildNode to this instance.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def insertChildByIndex(self, Index: int, ChildNode: XMutableTreeNode) -> None:
        """
        inserts ChildNode to this instance at the given index.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def removeChildByIndex(self, Index: int) -> None:
        """
        removes the node from this instance at the specified index.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def setCollapsedGraphicURL(self, URL: str) -> None:
        """
        The URL for a graphic that is rendered to visualize collapsed non leaf nodes.
        
        If URL is empty, XTreeControl.DefaultCollapsedGraphicURL is used.
        """
        ...
    @abstractmethod
    def setDisplayValue(self, Value: object) -> None:
        """
        sets the display value of this node
        """
        ...
    @abstractmethod
    def setExpandedGraphicURL(self, URL: str) -> None:
        """
        The URL for a graphic that is rendered to visualize expanded non leaf nodes.
        
        If URL is empty, XTreeControl.DefaultExpandedGraphicURL is used.
        """
        ...
    @abstractmethod
    def setHasChildrenOnDemand(self, ChildrenOnDemand: bool) -> None:
        """
        Changes if the children of this node are created on demand.
        """
        ...
    @abstractmethod
    def setNodeGraphicURL(self, URL: str) -> None:
        """
        The URL for a graphic that is rendered before the text part of this node.
        
        If this URL is empty, no graphic is rendered.
        """
        ...
    @abstractproperty
    def DataValue(self) -> object:
        """
        Stores an implementation dependent value.
        
        You can use this attribute to store data for this node that is independent of the display value
        """
        ...


__all__ = ['XMutableTreeNode']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .data_pilot_field_group_info import DataPilotFieldGroupInfo as DataPilotFieldGroupInfo_56691020
    from .x_data_pilot_field import XDataPilotField as XDataPilotField_e0350cdf

class XDataPilotFieldGrouping(XInterface_8f010a43):
    """
    Provides methods to create new DataPilot fields where some or all items of this DataPilot field are grouped in some way.

    See Also:
        `API XDataPilotFieldGrouping <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotFieldGrouping.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XDataPilotFieldGrouping'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XDataPilotFieldGrouping'

    @abstractmethod
    def createDateGroup(self, aInfo: DataPilotFieldGroupInfo_56691020) -> XDataPilotField_e0350cdf:
        """
        Groups the members of this field by dates, according to the passed settings.
        
        If this field is already grouped by dates, a new DataPilot field will be created and returned. If this field is not grouped at all, the date grouping is performed inside of this field (no new field will be created). There must not be any other grouping (by member names or by numeric ranges), otherwise an exception is thrown.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def createNameGroup(self, aItems: typing.Tuple[str, ...]) -> XDataPilotField_e0350cdf:
        """
        Creates a new DataPilot field which contains a group containing the given DataPilot field items (members).
        
        It is possible to create multiple groups by calling this method several times at the same DataPilot field. On subsequent calls, the DataPilot field created at the first call is used to insert the new groups.
        
        The collection of groups can be accessed via the DataPilotField.GroupInfo property. The returned struct contains the sequence of groups in its member DataPilotFieldGroupInfo.Groups.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XDataPilotFieldGrouping']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractmethod
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
if typing.TYPE_CHECKING:
    from .x_draw_page import XDrawPage as XDrawPage_b07a0b57

class XDrawPages(XIndexAccess_f0910d6d):
    """
    gives access to a container of DrawPages or MasterPages.
    
    The pages are stored in an index container. The order is determined by the index.
    
    You usually get this interface if you use the XDrawPagesSupplier or the XMasterPagesSupplier at a model that contains DrawPages or MasterPages

    See Also:
        `API XDrawPages <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XDrawPages.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.XDrawPages'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.XDrawPages'

    @abstractmethod
    def insertNewByIndex(self, nIndex: int) -> XDrawPage_b07a0b57:
        """
        creates and inserts a new DrawPage or MasterPage into this container
        """
        ...
    @abstractmethod
    def remove(self, xPage: XDrawPage_b07a0b57) -> None:
        """
        removes a DrawPage or MasterPage from this container.
        """
        ...

__all__ = ['XDrawPages']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
from abc import abstractproperty
from .file_connection_properties import FILEConnectionProperties as FILEConnectionProperties_4e7f1001

class DBASEConnectionProperties(FILEConnectionProperties_4e7f1001):
    """
    Service Class

    represents the properties for a dBase connection (session) with a specific database.
    
    These properties can be used when calling the method com.sun.star.sdbc.XDriver.connect() or com.sun.star.sdbc.XDriverManager.getConnectionWithInfo().
    
    The properties for a connection contain additional information about how to connect to a database and how to control the behavior of the resulting connection should be.

    See Also:
        `API DBASEConnectionProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbc_1_1DBASEConnectionProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.DBASEConnectionProperties'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ShowDeleted(self) -> bool:
        """
        TRUE when deleted rows should be shown, otherwise FALSE
        """
        ...


__all__ = ['DBASEConnectionProperties']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.presentation
from __future__ import annotations
from abc import abstractmethod
from ..animations.x_animation_listener import XAnimationListener as XAnimationListener_5c5a1079

class XSlideShowListener(XAnimationListener_5c5a1079):
    """
    Listener interface to receive global slide show events.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XSlideShowListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.presentation'
    __ooo_full_ns__: str = 'com.sun.star.presentation.XSlideShowListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.presentation.XSlideShowListener'

    @abstractmethod
    def hyperLinkClicked(self, hyperLink: str) -> None:
        """
        Notifies that a hyperlink has been clicked.
        """
        ...
    @abstractmethod
    def paused(self) -> None:
        """
        Notify that the slide show is paused.
        """
        ...
    @abstractmethod
    def resumed(self) -> None:
        """
        Notify that the slide show is resumed from a paused state.
        """
        ...
    @abstractmethod
    def slideAnimationsEnded(self) -> None:
        """
        Notify that the last animation from the main sequence of the current slide has ended.
        """
        ...
    @abstractmethod
    def slideEnded(self, reverse: bool) -> None:
        """
        Notify that the current slide has ended, e.g.
        
        the user has clicked on the slide. Calling displaySlide() twice will not issue this event.
        """
        ...
    @abstractmethod
    def slideTransitionEnded(self) -> None:
        """
        Notify that the slide transition of the current slide ended.
        """
        ...
    @abstractmethod
    def slideTransitionStarted(self) -> None:
        """
        Notify that a new slide starts to become visible.
        """
        ...

__all__ = ['XSlideShowListener']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.dom
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_node import XNode as XNode_83fb09a5

class XNamedNodeMap(XInterface_8f010a43):
    """

    See Also:
        `API XNamedNodeMap <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XNamedNodeMap.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.dom'
    __ooo_full_ns__: str = 'com.sun.star.xml.dom.XNamedNodeMap'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.dom.XNamedNodeMap'

    @abstractmethod
    def getLength(self) -> int:
        """
        The number of nodes in this map.
        """
        ...
    @abstractmethod
    def getNamedItem(self, name: str) -> XNode_83fb09a5:
        """
        Retrieves a node specified by local name.
        """
        ...
    @abstractmethod
    def getNamedItemNS(self, namespaceURI: str, localName: str) -> XNode_83fb09a5:
        """
        Retrieves a node specified by local name and namespace URI.
        """
        ...
    @abstractmethod
    def item(self, index: int) -> XNode_83fb09a5:
        """
        Returns a node specified by index.
        """
        ...
    @abstractmethod
    def removeNamedItem(self, name: str) -> XNode_83fb09a5:
        """
        Removes a node specified by name.
        
        Throws: DOMException - NOT_FOUND_ERR: Raised if there is no node named name in this map. NO_MODIFICATION_ALLOWED_ERR: Raised if this map is readonly.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def removeNamedItemNS(self, namespaceURI: str, localName: str) -> XNode_83fb09a5:
        """
        Removes a node specified by local name and namespace URI.
        
        Throws: DOMException - NOT_FOUND_ERR: Raised if there is no node with the specified namespaceURI and localName in this map. NO_MODIFICATION_ALLOWED_ERR: Raised if this map is readonly.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def setNamedItem(self, arg: XNode_83fb09a5) -> XNode_83fb09a5:
        """
        Adds a node using its nodeName attribute.
        
        Throws: DOMException - WRONG_DOCUMENT_ERR: Raised if arg was created from a different document than the one that created this map. NO_MODIFICATION_ALLOWED_ERR: Raised if this map is readonly. INUSE_ATTRIBUTE_ERR: Raised if arg is an Attr that is already an attribute of another Element object. The DOM user must explicitly clone Attr nodes to re-use them in other elements. HIERARCHY_REQUEST_ERR: Raised if an attempt is made to add a node doesn't belong in this NamedNodeMap. Examples would include trying to insert something other than an Attr node into an Element's map of attributes, or a non-Entity node into the DocumentType's map of Entities.

        Raises:
            DOMException: ``DOMException``
        """
        ...
    @abstractmethod
    def setNamedItemNS(self, arg: XNode_83fb09a5) -> XNode_83fb09a5:
        """
        Adds a node using its namespaceURI and localName.
        
        Throws: DOMException - WRONG_DOCUMENT_ERR: Raised if arg was created from a different document than the one that created this map. NO_MODIFICATION_ALLOWED_ERR: Raised if this map is readonly. INUSE_ATTRIBUTE_ERR: Raised if arg is an Attr that is already an attribute of another Element object. The DOM user must explicitly clone Attr nodes to re-use them in other elements. HIERARCHY_REQUEST_ERR: Raised if an attempt is made to add a node doesn't belong in this NamedNodeMap. Examples would include trying to insert something other than an Attr node into an Element's map of attributes, or a non-Entity node into the DocumentType's map of Entities. NOT_SUPPORTED_ERR: Always thrown if the current document does not support the \"XML\" feature, since namespaces were defined by XML.

        Raises:
            DOMException: ``DOMException``
        """
        ...

__all__ = ['XNamedNodeMap']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.sheet.CellInsertMode import CellInsertModeProto

class CellInsertMode(Enum):
    """
    Enum Class


    See Also:
        `API CellInsertMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet.html#a93cdb08109d5d34543f2fe04d1ef605a>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.CellInsertMode'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.sheet.CellInsertMode'

    COLUMNS = cast("CellInsertModeProto", 'COLUMNS')
    """
    entire columns to the right of the deleted cells are moved left.
    
    entire columns to the right of the inserted cells are moved right.
    """
    DOWN = cast("CellInsertModeProto", 'DOWN')
    """
    the cells below the inserted cells are moved down.
    """
    NONE = cast("CellInsertModeProto", 'NONE')
    """
    no cells are moved.
    
    sheet is not linked.
    
    new values are used without changes.
    
    nothing is calculated.
    
    nothing is imported.
    
    no condition is specified.
    """
    RIGHT = cast("CellInsertModeProto", 'RIGHT')
    """
    selects the right border.
    
    the cells to the right of the inserted cells are moved right.
    """
    ROWS = cast("CellInsertModeProto", 'ROWS')
    """
    entire rows below the deleted cells are moved up.
    
    entire rows below the inserted cells are moved down.
    """

__all__ = ['CellInsertMode']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_sprite import XSprite as XSprite_b2470b95
if typing.TYPE_CHECKING:
    from ..geometry.real_point2_d import RealPoint2D as RealPoint2D_d6e70c78
    from .render_state import RenderState as RenderState_e4490d27
    from .view_state import ViewState as ViewState_cab30c62

class XAnimatedSprite(XSprite_b2470b95):
    """
    This interface can be used to control an animated sprite object.
    
    This interface can be used to control an animated sprite object on an XSpriteCanvas. Sprites are moving, animated objects.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XAnimatedSprite <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XAnimatedSprite.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.XAnimatedSprite'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rendering.XAnimatedSprite'

    @abstractmethod
    def resetAnimation(self) -> None:
        """
        Reset the animation sequence to start with the first frame.
        
        If the animation is currently running, the next frame that is drawn after this method has finished, will be the first one. Please note that if an animation is not started, the associated XSpriteCanvas does not update changed sprites automatically.
        """
        ...
    @abstractmethod
    def setAll(self, aNewPos: RealPoint2D_d6e70c78, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27, nAlpha: float, bUpdateAnimation: bool) -> None:
        """
        Changes all of the sprite's attributes at one atomic instance.
        
        This is useful at times where one does not want multiple redraws for every state change.
        
        Please note that if an animation is not started, the associated XSpriteCanvas does not update changed sprites automatically, but has to be told to do so via XSpriteCanvas.updateScreen().

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def setViewState(self, aViewState: ViewState_cab30c62) -> None:
        """
        Changes the view state in place for this sprite's animation.
        
        The state given here is used when calling the XAnimation.render() method, or when drawing the sprite's bitmaps, respectively. There's no need to call XSpriteCanvas.updateAnimation() after this method, as it automatically rerenders, if necessary. Please note that if an animation is not started, the associated XSpriteCanvas does not update changed sprites automatically, but has to be told to do so via XSpriteCanvas.updateScreen().

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def startAnimation(self, nSpeed: float) -> None:
        """
        Start animation sequence of this sprite.
        
        The speed of the animation is given in cycles per second (where a cycle is defined as one full animation run, i.e. the full [0,1] range of the XAnimation.render()'s t parameter, or a full sequence of sprite bitmaps drawn). Once an animation is running, the associated XSpriteCanvas handles screen updates automatically. That means, changes to position or alpha are reflected on screen automatically. Please note further that sprite visibility and animation are unrelated, i.e. a hidden sprite can have a running animation, which then displays in the middle of the animation sequence, when a show() is called later on.
        """
        ...
    @abstractmethod
    def stopAnimation(self) -> None:
        """
        Stop the animation sequence.
        
        A subsequent XAnimatedSprite.startAnimation() will commence the sequence at the point where it was stopped with here. Once an animation is stopped, the associated XSpriteCanvas does not update changed sprites anymore.
        """
        ...
    @abstractmethod
    def updateAnimation(self) -> None:
        """
        Issue an additional render call to this sprite's animation.
        
        This method has no effect when called for a bitmap-sequence sprite. Please note that if an animation is not started, the associated XSpriteCanvas does not update changed sprites automatically, but has to be told to do so via XSpriteCanvas.updateScreen().
        """
        ...

__all__ = ['XAnimatedSprite']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..linguistic2.x_hyphenated_word import XHyphenatedWord as XHyphenatedWord_3a880f73


class LineBreakResults(object):
    """
    Struct Class

    Results of method XBreakIterator.getLineBreak().

    See Also:
        `API LineBreakResults <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1LineBreakResults.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.LineBreakResults'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.i18n.LineBreakResults'
    """Literal Constant ``com.sun.star.i18n.LineBreakResults``"""

    def __init__(self, breakType: typing.Optional[int] = 0, breakIndex: typing.Optional[int] = 0, rHyphenatedWord: typing.Optional[XHyphenatedWord_3a880f73] = None) -> None:
        """
        Constructor

        Arguments:
            breakType (int, optional): breakType value.
            breakIndex (int, optional): breakIndex value.
            rHyphenatedWord (XHyphenatedWord, optional): rHyphenatedWord value.
        """
        super().__init__()

        if isinstance(breakType, LineBreakResults):
            oth: LineBreakResults = breakType
            self.breakType = oth.breakType
            self.breakIndex = oth.breakIndex
            self.rHyphenatedWord = oth.rHyphenatedWord
            return

        kargs = {
            "breakType": breakType,
            "breakIndex": breakIndex,
            "rHyphenatedWord": rHyphenatedWord,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._break_type = kwargs["breakType"]
        self._break_index = kwargs["breakIndex"]
        self._r_hyphenated_word = kwargs["rHyphenatedWord"]


    @property
    def breakType(self) -> int:
        """
        Type of line break, see BreakType.
        """
        return self._break_type

    @breakType.setter
    def breakType(self, value: int) -> None:
        self._break_type = value

    @property
    def breakIndex(self) -> int:
        """
        Position of the calculated line break.
        """
        return self._break_index

    @breakIndex.setter
    def breakIndex(self, value: int) -> None:
        self._break_index = value

    @property
    def rHyphenatedWord(self) -> XHyphenatedWord_3a880f73:
        """
        Return value of the hyphenator.
        """
        return self._r_hyphenated_word

    @rHyphenatedWord.setter
    def rHyphenatedWord(self, value: XHyphenatedWord_3a880f73) -> None:
        self._r_hyphenated_word = value


__all__ = ['LineBreakResults']
